/****************************************************************************
** Meta object code from reading C++ file 'pipewiresourceitem.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kpipewire-6.7.4/src/pipewiresourceitem.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'pipewiresourceitem.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18PipeWireSourceItemE_t {};
} // unnamed namespace

template <> constexpr inline auto PipeWireSourceItem::qt_create_metaobjectdata<qt_meta_tag_ZN18PipeWireSourceItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PipeWireSourceItem",
        "QML.Element",
        "auto",
        "nodeIdChanged",
        "",
        "nodeId",
        "fdChanged",
        "fd",
        "streamSizeChanged",
        "stateChanged",
        "usingDmaBufChanged",
        "readyChanged",
        "paintedRectChanged",
        "objectSerialChanged",
        "invalidateSceneGraph",
        "updatePaintedRect",
        "error",
        "state",
        "StreamState",
        "objectSerial",
        "streamSize",
        "QSize",
        "allowDmaBuf",
        "usingDmaBuf",
        "ready",
        "paintedRect",
        "QRectF",
        "Error",
        "Unconnected",
        "Connecting",
        "Paused",
        "Streaming"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'nodeIdChanged'
        QtMocHelpers::SignalData<void(uint)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 5 },
        }}),
        // Signal 'fdChanged'
        QtMocHelpers::SignalData<void(uint)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 7 },
        }}),
        // Signal 'streamSizeChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'usingDmaBufChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'readyChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'paintedRectChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'objectSerialChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'invalidateSceneGraph'
        QtMocHelpers::SlotData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updatePaintedRect'
        QtMocHelpers::SlotData<void()>(15, 4, QMC::AccessPrivate, QMetaType::Void),
        // Method 'error'
        QtMocHelpers::MethodData<QString() const>(16, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'state'
        QtMocHelpers::PropertyData<enum StreamState>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'nodeId'
        QtMocHelpers::PropertyData<uint>(5, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'objectSerial'
        QtMocHelpers::PropertyData<quint64>(19, QMetaType::ULongLong, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'fd'
        QtMocHelpers::PropertyData<uint>(7, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet, 1),
        // property 'streamSize'
        QtMocHelpers::PropertyData<QSize>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'allowDmaBuf'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'usingDmaBuf'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
        // property 'ready'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags, 5),
        // property 'paintedRect'
        QtMocHelpers::PropertyData<QRectF>(25, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 6),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'StreamState'
        QtMocHelpers::EnumData<enum StreamState>(18, 18, QMC::EnumIsScoped).add({
            {   27, StreamState::Error },
            {   28, StreamState::Unconnected },
            {   29, StreamState::Connecting },
            {   30, StreamState::Paused },
            {   31, StreamState::Streaming },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<PipeWireSourceItem, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PipeWireSourceItem::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18PipeWireSourceItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18PipeWireSourceItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18PipeWireSourceItemE_t>.metaTypes,
    nullptr
} };

void PipeWireSourceItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PipeWireSourceItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->nodeIdChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 1: _t->fdChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 2: _t->streamSizeChanged(); break;
        case 3: _t->stateChanged(); break;
        case 4: _t->usingDmaBufChanged(); break;
        case 5: _t->readyChanged(); break;
        case 6: _t->paintedRectChanged(); break;
        case 7: _t->objectSerialChanged(); break;
        case 8: _t->invalidateSceneGraph(); break;
        case 9: _t->updatePaintedRect(); break;
        case 10: { QString _r = _t->error();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PipeWireSourceItem::*)(uint )>(_a, &PipeWireSourceItem::nodeIdChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PipeWireSourceItem::*)(uint )>(_a, &PipeWireSourceItem::fdChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PipeWireSourceItem::*)()>(_a, &PipeWireSourceItem::streamSizeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PipeWireSourceItem::*)()>(_a, &PipeWireSourceItem::stateChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PipeWireSourceItem::*)()>(_a, &PipeWireSourceItem::usingDmaBufChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PipeWireSourceItem::*)()>(_a, &PipeWireSourceItem::readyChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (PipeWireSourceItem::*)()>(_a, &PipeWireSourceItem::paintedRectChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (PipeWireSourceItem::*)()>(_a, &PipeWireSourceItem::objectSerialChanged, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum StreamState*>(_v) = _t->state(); break;
        case 1: *reinterpret_cast<uint*>(_v) = _t->nodeId(); break;
        case 2: *reinterpret_cast<quint64*>(_v) = _t->objectSerial(); break;
        case 3: *reinterpret_cast<uint*>(_v) = _t->fd(); break;
        case 4: *reinterpret_cast<QSize*>(_v) = _t->streamSize(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->allowDmaBuf(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->usingDmaBuf(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isReady(); break;
        case 8: *reinterpret_cast<QRectF*>(_v) = _t->paintedRect(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setNodeId(*reinterpret_cast<uint*>(_v)); break;
        case 2: _t->setObjectSerial(*reinterpret_cast<quint64*>(_v)); break;
        case 3: _t->setFd(*reinterpret_cast<uint*>(_v)); break;
        case 5: _t->setAllowDmaBuf(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 3: _t->resetFd(); break;
        default: break;
        }
    }
}

const QMetaObject *PipeWireSourceItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PipeWireSourceItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18PipeWireSourceItemE_t>.strings))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int PipeWireSourceItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void PipeWireSourceItem::nodeIdChanged(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void PipeWireSourceItem::fdChanged(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void PipeWireSourceItem::streamSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void PipeWireSourceItem::stateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void PipeWireSourceItem::usingDmaBufChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void PipeWireSourceItem::readyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void PipeWireSourceItem::paintedRectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void PipeWireSourceItem::objectSerialChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
