/****************************************************************************
** Meta object code from reading C++ file 'pipewirebaseencodedstream.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kpipewire-6.7.4/src/pipewirebaseencodedstream.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'pipewirebaseencodedstream.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN25PipeWireBaseEncodedStreamE_t {};
} // unnamed namespace

template <> constexpr inline auto PipeWireBaseEncodedStream::qt_create_metaobjectdata<qt_meta_tag_ZN25PipeWireBaseEncodedStreamE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PipeWireBaseEncodedStream",
        "activeChanged",
        "",
        "active",
        "nodeIdChanged",
        "nodeId",
        "fdChanged",
        "fd",
        "errorFound",
        "error",
        "maxFramerateChanged",
        "maxPendingFramesChanged",
        "stateChanged",
        "encoderChanged",
        "objectSerialChanged",
        "start",
        "stop",
        "objectSerial",
        "state",
        "State",
        "encoder",
        "Encoder",
        "NoEncoder",
        "VP8",
        "VP9",
        "H264Main",
        "H264Baseline",
        "WebP",
        "Gif",
        "Idle",
        "Recording",
        "Rendering",
        "EncodingPreference",
        "NoPreference",
        "Quality",
        "Speed",
        "Size",
        "ColorRange",
        "Limited",
        "Full"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'activeChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'nodeIdChanged'
        QtMocHelpers::SignalData<void(uint)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 5 },
        }}),
        // Signal 'fdChanged'
        QtMocHelpers::SignalData<void(uint)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 7 },
        }}),
        // Signal 'errorFound'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'maxFramerateChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maxPendingFramesChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'encoderChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'objectSerialChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'start'
        QtMocHelpers::MethodData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'stop'
        QtMocHelpers::MethodData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'nodeId'
        QtMocHelpers::PropertyData<uint>(5, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'objectSerial'
        QtMocHelpers::PropertyData<quint64>(17, QMetaType::ULongLong, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'fd'
        QtMocHelpers::PropertyData<uint>(7, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'active'
        QtMocHelpers::PropertyData<bool>(3, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'state'
        QtMocHelpers::PropertyData<enum State>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 6),
        // property 'encoder'
        QtMocHelpers::PropertyData<enum Encoder>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Encoder'
        QtMocHelpers::EnumData<enum Encoder>(21, 21, QMC::EnumFlags{}).add({
            {   22, Encoder::NoEncoder },
            {   23, Encoder::VP8 },
            {   24, Encoder::VP9 },
            {   25, Encoder::H264Main },
            {   26, Encoder::H264Baseline },
            {   27, Encoder::WebP },
            {   28, Encoder::Gif },
        }),
        // enum 'State'
        QtMocHelpers::EnumData<enum State>(19, 19, QMC::EnumFlags{}).add({
            {   29, State::Idle },
            {   30, State::Recording },
            {   31, State::Rendering },
        }),
        // enum 'EncodingPreference'
        QtMocHelpers::EnumData<enum EncodingPreference>(32, 32, QMC::EnumFlags{}).add({
            {   33, EncodingPreference::NoPreference },
            {   34, EncodingPreference::Quality },
            {   35, EncodingPreference::Speed },
            {   36, EncodingPreference::Size },
        }),
        // enum 'ColorRange'
        QtMocHelpers::EnumData<enum ColorRange>(37, 37, QMC::EnumIsScoped).add({
            {   38, ColorRange::Limited },
            {   39, ColorRange::Full },
        }),
    };
    return QtMocHelpers::metaObjectData<PipeWireBaseEncodedStream, qt_meta_tag_ZN25PipeWireBaseEncodedStreamE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PipeWireBaseEncodedStream::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25PipeWireBaseEncodedStreamE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25PipeWireBaseEncodedStreamE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25PipeWireBaseEncodedStreamE_t>.metaTypes,
    nullptr
} };

void PipeWireBaseEncodedStream::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PipeWireBaseEncodedStream *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->activeChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->nodeIdChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 2: _t->fdChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 3: _t->errorFound((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->maxFramerateChanged(); break;
        case 5: _t->maxPendingFramesChanged(); break;
        case 6: _t->stateChanged(); break;
        case 7: _t->encoderChanged(); break;
        case 8: _t->objectSerialChanged(); break;
        case 9: _t->start(); break;
        case 10: _t->stop(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PipeWireBaseEncodedStream::*)(bool )>(_a, &PipeWireBaseEncodedStream::activeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PipeWireBaseEncodedStream::*)(uint )>(_a, &PipeWireBaseEncodedStream::nodeIdChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PipeWireBaseEncodedStream::*)(uint )>(_a, &PipeWireBaseEncodedStream::fdChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PipeWireBaseEncodedStream::*)(const QString & )>(_a, &PipeWireBaseEncodedStream::errorFound, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PipeWireBaseEncodedStream::*)()>(_a, &PipeWireBaseEncodedStream::maxFramerateChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PipeWireBaseEncodedStream::*)()>(_a, &PipeWireBaseEncodedStream::maxPendingFramesChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (PipeWireBaseEncodedStream::*)()>(_a, &PipeWireBaseEncodedStream::stateChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (PipeWireBaseEncodedStream::*)()>(_a, &PipeWireBaseEncodedStream::encoderChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (PipeWireBaseEncodedStream::*)()>(_a, &PipeWireBaseEncodedStream::objectSerialChanged, 8))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<uint*>(_v) = _t->nodeId(); break;
        case 1: *reinterpret_cast<quint64*>(_v) = _t->objectSerial(); break;
        case 2: *reinterpret_cast<uint*>(_v) = _t->fd(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isActive(); break;
        case 4: *reinterpret_cast<enum State*>(_v) = _t->state(); break;
        case 5: *reinterpret_cast<enum Encoder*>(_v) = _t->encoder(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setNodeId(*reinterpret_cast<uint*>(_v)); break;
        case 1: _t->setObjectSerial(*reinterpret_cast<quint64*>(_v)); break;
        case 2: _t->setFd(*reinterpret_cast<uint*>(_v)); break;
        case 5: _t->setEncoder(*reinterpret_cast<enum Encoder*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *PipeWireBaseEncodedStream::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PipeWireBaseEncodedStream::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25PipeWireBaseEncodedStreamE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int PipeWireBaseEncodedStream::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void PipeWireBaseEncodedStream::activeChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void PipeWireBaseEncodedStream::nodeIdChanged(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void PipeWireBaseEncodedStream::fdChanged(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void PipeWireBaseEncodedStream::errorFound(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void PipeWireBaseEncodedStream::maxFramerateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void PipeWireBaseEncodedStream::maxPendingFramesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void PipeWireBaseEncodedStream::stateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void PipeWireBaseEncodedStream::encoderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void PipeWireBaseEncodedStream::objectSerialChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
