/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<pipewirerecord.h>)
#  include <pipewirerecord.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_pipewire_record()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    QMetaType::fromType<PipeWireBaseEncodedStream *>().id();
    qmlRegisterEnum<PipeWireBaseEncodedStream::Encoder>("PipeWireBaseEncodedStream::Encoder");
    qmlRegisterEnum<PipeWireBaseEncodedStream::State>("PipeWireBaseEncodedStream::State");
    qmlRegisterEnum<PipeWireBaseEncodedStream::EncodingPreference>("PipeWireBaseEncodedStream::EncodingPreference");
    qmlRegisterEnum<PipeWireBaseEncodedStream::ColorRange>("PipeWireBaseEncodedStream::ColorRange");
    qmlRegisterTypesAndRevisions<PipeWireRecord>("org.kde.pipewire.record", 1);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.pipewire.record", 1, 0);
}

static const QQmlModuleRegistration orgkdepipewirerecordRegistration("org.kde.pipewire.record", qml_register_types_org_kde_pipewire_record);
