// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "logging_frame_statistics.h"


Q_LOGGING_CATEGORY(PIPEWIRERECORDFRAMESTATS_LOGGING, "kpipewire_record_framestatistics", QtInfoMsg)

